@@ -23,7 +23,7 @@ from builtins import str
 
 from functools import cmp_to_key
 
-from qgis.core import Qgis
+from qgis.core import Qgis, QgsSqliteUtils
 from qgis.PyQt.QtCore import QFile
 from qgis.PyQt.QtWidgets import QApplication
 
@@ -59,6 +59,12 @@ class SpatiaLiteDBConnector(DBConnector):
     def _connectionInfo(self):
         return str(self.dbname)
 
+    def cancel(self):
+        # https://www.sqlite.org/c3ref/interrupt.html
+        # This function causes any pending database operation to abort and return at its earliest opportunity.
+        if self.connection:
+            self.connection.interrupt()
+
     @classmethod
     def isValidDatabase(self, path):
         if not QFile.exists(path):
@@ -165,18 +171,7 @@ class SpatiaLiteDBConnector(DBConnector):
         tablenames = []
         items = []
 
-        sys_tables = ["SpatialIndex", "geom_cols_ref_sys", "geometry_columns", "geometry_columns_auth",
-                      "views_geometry_columns", "virts_geometry_columns", "spatial_ref_sys",
-                      "sqlite_sequence",  # "tableprefix_metadata", "tableprefix_rasters",
-                      "layer_params", "layer_statistics", "layer_sub_classes", "layer_table_layout",
-                      "pattern_bitmaps", "symbol_bitmaps", "project_defs", "raster_pyramids",
-                      "sqlite_stat1", "sqlite_stat2", "spatialite_history",
-                      "geometry_columns_field_infos",
-                      "geometry_columns_statistics", "geometry_columns_time",
-                      "sql_statements_log", "vector_layers", "vector_layers_auth", "vector_layers_field_infos", "vector_layers_statistics",
-                      "views_geometry_columns_auth", "views_geometry_columns_field_infos", "views_geometry_columns_statistics",
-                      "virts_geometry_columns_auth", "virts_geometry_columns_field_infos", "virts_geometry_columns_statistics"
-                      ]
+        sys_tables = QgsSqliteUtils.systemTables()
 
         try:
             vectors = self.getVectorTables(schema)
@@ -458,6 +453,8 @@ class SpatiaLiteDBConnector(DBConnector):
         self._execute(c, sql)
         self._commit()
 
+        return True
+
     def emptyTable(self, table):
         """ delete all rows from table """
         if self.isRasterTable(table):
@@ -487,6 +484,7 @@ class SpatiaLiteDBConnector(DBConnector):
             self._execute(c, sql)
 
         self._commit()
+        return True
 
     def moveTable(self, table, new_table, new_schema=None):
         return self.renameTable(table, new_table)
@@ -564,7 +562,16 @@ class SpatiaLiteDBConnector(DBConnector):
     def addTableColumn(self, table, field_def):
         """ add a column to table """
         sql = u"ALTER TABLE %s ADD %s" % (self.quoteId(table), field_def)
-        self._execute_and_commit(sql)
+        self._execute(None, sql)
+
+        sql = u"SELECT InvalidateLayerStatistics(%s)" % (self.quoteId(table))
+        self._execute(None, sql)
+
+        sql = u"SELECT UpdateLayerStatistics(%s)" % (self.quoteId(table))
+        self._execute(None, sql)
+
+        self._commit()
+        return True
 
     def deleteTableColumn(self, table, column):
         """ delete column from a table """
@@ -576,7 +583,7 @@ class SpatiaLiteDBConnector(DBConnector):
         sql = u"SELECT DiscardGeometryColumn(%s, %s)" % (self.quoteString(tablename), self.quoteString(column))
         self._execute_and_commit(sql)
 
-    def updateTableColumn(self, table, column, new_name, new_data_type=None, new_not_null=None, new_default=None):
+    def updateTableColumn(self, table, column, new_name, new_data_type=None, new_not_null=None, new_default=None, comment=None):
         return False  # column editing not supported
 
     def renameTableColumn(self, table, column, new_name):
